@@ -736,13 +736,16 @@ check_for_vpd (GUdevDevice *device)
 
   g_return_val_if_fail (G_UDEV_IS_DEVICE (device), FALSE);
 
-  /* order of preference: WWN, serial, path */
+  /* order of preference: WWN_serial, WWN, serial, path */
   serial = g_udev_device_get_property (device, "ID_SERIAL");
   wwn = g_udev_device_get_property (device, "ID_WWN_WITH_EXTENSION");
   path = g_udev_device_get_property (device, "ID_PATH");
   if (wwn != NULL && strlen (wwn) > 0 && !is_wwn_black_listed (wwn))
     {
-      ret = g_strdup (wwn);
+      if (serial != NULL && strlen (serial) > 0)
+        ret = g_strdup_printf ("%s_%s", wwn, serial);
+      else
+        ret = g_strdup (wwn);
     }
   else if (serial != NULL && strlen (serial) > 0)
     {
